package com.businesscompassllc.sqlitedemo;
import java.util.ArrayList;
import java.util.List;

import android.content.ContentValues;
import android.content.Context;
import android.database.Cursor;
import android.database.SQLException;
import android.database.sqlite.SQLiteCursor;
import android.database.sqlite.SQLiteCursorDriver;
import android.database.sqlite.SQLiteDatabase;
import android.database.sqlite.SQLiteOpenHelper;
import android.database.sqlite.SQLiteQuery;
import android.util.Log;

/**
 * Provides access to the MicroJobs database. Since this is not a Content Provider, 
 * no other applications will have access to the database.
 */

public class PartDB extends SQLiteOpenHelper {
    /** The name of the database file on the file system */
    private static final String DATABASE_NAME = "PartDB";
    /** The version of the database that this class understands. */
    private static final int DATABASE_VERSION = 1;
    
    // Contacts table name
    private static final String TABLE_PART = "part";
 
    // Contacts Table Columns names
    private static final String COL_NUMBER = "part_number";
    private static final String COL_NAME = "part_name";
    private static final String COL_PRICE = "part_price";
    public static final String COL_ID = "_id";
    
    /** Keep track of context so that we can load SQL from string resources */
    private final Context mContext;

    /** Constructor */
    public PartDB(Context context) {
        super(context, DATABASE_NAME, null, DATABASE_VERSION);
        this.mContext = context;
    }

    /** Called when it is time to create the database */
    public void onCreate(SQLiteDatabase db) {
        String[] sql = 
          mContext.getString(R.string.PartDB_onCreate).split("\n");
        db.beginTransaction();
        try {
            // Create tables and test data
            execMultipleSQL(db, sql);
            db.setTransactionSuccessful();
        } catch (SQLException e) {
            Log.e("Error creating tables and debug data", e.toString());
            throw e;
        } finally {
            db.endTransaction();
        }
    }

    /** Called when the database must be upgraded */
    
    public void onUpgrade(SQLiteDatabase db, int oldVersion, int newVersion) {
        Log.w(PartDB.DATABASE_NAME, "Upgrading database from version " + oldVersion + 
          " to " +
            newVersion + ", which will destroy all old data");

        String[] sql = 
          mContext.getString(R.string.PartDB_onUpgrade).split("\n");
        db.beginTransaction();
        try {
            execMultipleSQL(db, sql);
            db.setTransactionSuccessful();
        } catch (SQLException e) {
            Log.e("Error upgrading tables and debug data", e.toString());
            throw e;
        } finally {
            db.endTransaction();
        }

        // This is cheating.  In the real world, you'll need to add columns, not 
        //   rebuild from scratch.
        onCreate(db);
    }

    /**
     * Execute all of the SQL statements in the String[] array
     * @param db The database on which to execute the statements
     * @param sql An array of SQL statements to execute
     */
    private void execMultipleSQL(SQLiteDatabase db, String[] sql){
        for( String s : sql )
            if (s.trim().length()>0)
                db.execSQL(s);
    }


    

    public Part getPart(int number) {

        SQLiteDatabase db = this.getReadableDatabase();
     
        Cursor cursor = db.query(TABLE_PART, new String[] { COL_NUMBER,
                COL_NAME, COL_PRICE }, COL_NUMBER + "=?",
                new String[] { String.valueOf(number) }, null, null, null, null);
        if (cursor != null)
            cursor.moveToFirst();
     
        Part part = new Part();
        part.setNumber(cursor.getInt(0));
        part.setName(cursor.getString(1));
        part.setPrice(cursor.getDouble(2));
        
        // return part
        return part;
    }

    public List<Part> getAllParts() {
        List<Part> partList = new ArrayList<Part>();
        // Select All Query
        String selectQuery = "SELECT  part_number, part_name, part_price FROM " + TABLE_PART + " order by part_number";
     
        SQLiteDatabase db = this.getWritableDatabase();
        Cursor cursor = db.rawQuery(selectQuery, null);
     
        // looping through all rows and adding to list
        if (cursor.moveToFirst()) {
            do {
                Part part = new Part();
                part.setNumber(cursor.getInt(0));
                part.setName(cursor.getString(1));
                part.setPrice(cursor.getDouble(2));
                
                Log.e("ALL", "PARTS" );
                Log.e("COL_NUMBER", "" +cursor.getInt(0));
                Log.e("COL_NAME", "" + cursor.getString(1));
                Log.e("COL_PRICE", "" +cursor.getDouble(2));
                
                // Adding contact to list
                partList.add(part);
            } while (cursor.moveToNext());
        }
     
        // return contact list
        return partList;
    }

   
    public int getPartCount() {
        String countQuery = "SELECT  * FROM " + TABLE_PART;
        SQLiteDatabase db = this.getReadableDatabase();
        Cursor cursor = db.rawQuery(countQuery, null);
        
        int count=cursor.getCount();
        
        cursor.close();
 
        // return count
        return count;
    }
    
    void addPart(Part part) {
        SQLiteDatabase db = this.getWritableDatabase();
 
        ContentValues values = new ContentValues();
        values.put(COL_NUMBER, part.getNumber());
        values.put(COL_NAME, part.getName());
        values.put(COL_PRICE, part.getPrice());
 
        Log.e("INSERT", "PART" );
        Log.e("COL_NUMBER", "" +part.getNumber());
        Log.e("COL_NAME", "" +part.getName());
        Log.e("COL_PRICE", "" +part.getPrice());
        // Inserting Row
        db.insert(TABLE_PART, null, values);
       // db.close(); // Closing database connection
    }
 
    
    
    public int updatePart(Part part) {
        SQLiteDatabase db = this.getWritableDatabase();
 
        ContentValues values = new ContentValues();
        values.put(COL_NAME, part.getName());
        values.put(COL_PRICE, part.getPrice());
 
        // updating row
        return db.update(TABLE_PART, values, COL_NUMBER + " = ?",
                new String[] { String.valueOf(part.getNumber()) });
    }
 
    
    /*
public void UpdatePart(int number,String name, double price) {
    String sql = 
        "UPDATE part " +
        "SET part_name = ?,"+
        "    part_price = ?"+
        "WHERE part_number = ? ";
    Object[] bindArgs = new Object[]{name, price, number};
    try{
        getWritableDatabase().execSQL(sql, bindArgs);
    } catch (SQLException e) {
        Log.e("Error updating parr table", e.toString());
    }
}



public void insertPart(int number,String name, double price) {
    String sql = 
    	"INSERT INTO parts (_id,part_number,part_name,part_price) VALUES (NULL,?, ?,?)";
      
    Object[] bindArgs = new Object[]{number, name, price};
    try{
        getWritableDatabase().execSQL(sql, bindArgs);
    } catch (SQLException e) {
        Log.e("Error inserting into part table", e.toString());
    }
}
*/

public void createPartTable() {
    String sql = 
    	"CREATE TABLE part (_id INTEGER PRIMARY KEY AUTOINCREMENT,part_number INTEGER, part_name STRING, part_price double)";
    
    Object[] bindArgs = new Object[]{};
    try{
        getWritableDatabase().execSQL(sql, bindArgs);
    } catch (SQLException e) {
        Log.e("Error creating part table", e.toString());
    }
}


public void dropPartTable() {
    String sql = 
    	"drop table part";
    
    Object[] bindArgs = new Object[]{};
    try{
        getWritableDatabase().execSQL(sql, bindArgs);
    } catch (SQLException e) {
        Log.e("Error dropping part table", e.toString());
    }
}



public void deletePart(Part part) {
	
	Log.e("DELETE"," " + part.getNumber());
	
    SQLiteDatabase db = this.getWritableDatabase();
    db.delete(TABLE_PART, COL_NUMBER + " = ?",
            new String[] { String.valueOf(part.getNumber()) });
   // db.close();
}

public void deleteAllPart() {
    SQLiteDatabase db = this.getWritableDatabase();
    db.delete(TABLE_PART, null,
            null);
  //  db.close();
}

/*
    public void deletePart(int number) {
        String sql = 
            "DELETE part where part_number=?";
        
        Object[] bindArgs = new Object[]{number};
        
        try{
            getWritableDatabase().execSQL(sql, bindArgs);
        } catch (SQLException e) {
            Log.e("Error dateting part", e.toString());
        }
    }

    
    
    
    
    public void deleteAllParts() {
        String sql = 
            "DELETE part";
        
        Object[] bindArgs = new Object[]{};
        
        try{
            getWritableDatabase().execSQL(sql, bindArgs);
        } catch (SQLException e) {
            Log.e("Error deleting part table entirely", e.toString());
        }
    }
    */
    
    public void dropPartIndexe() {
        String sql = 
            "drop index  part_index;";
        
        Object[] bindArgs = new Object[]{};
        
        try{
            getWritableDatabase().execSQL(sql, bindArgs);
        } catch (SQLException e) {
            Log.e("Error dropping part index", e.toString());
        }
    }

    
    public void buildPartIndex() {
        String sql = 
        "create index part_index ON part (part_number);" ;
        
        Object[] bindArgs = new Object[]{};
        
        try{
            getWritableDatabase().execSQL(sql, bindArgs);
        } catch (SQLException e) {
            Log.e("Error building part index", e.toString());
        }
    }
    
}
